@@ -3,13 +3,18 @@ from transformers import T5TokenizerFast
 from transformers import AutoTokenizer
 import os
 
-def load_tokenizer(tokenizer_name, model, dir_path, file_name, model_name = None):
+BCP_47_languages = {
+    'french': 'fra_Latn',
+    'wolof': 'wol_Latn',
+}
+
+def load_tokenizer(tokenizer_name, model, dir_path, file_name, model_name = None, src_lang = "french", tgt_lang = "wolof"):
     
     if model == "nllb":
         
         if not model_name is None:
         
-            tokenizer = AutoTokenizer.from_pretrained(model_name)
+            tokenizer = AutoTokenizer.from_pretrained(model_name, src_lang = BCP_47_languages[src_lang], tgt_lang = BCP_47_languages[tgt_lang])
             
             print(f"The {model}'s tokenizer was successfully loaded")
         
